# Changelog

## [Unreleased]

## [0.1.1] - 2020-09-23

### Fixed

- Increased websocket limit
- Try windows compat for signals
- Always set PYTHONBREAKPOINT to kalong.breakpoint while running

## [0.1.0] - 2020-09-23

### Added

- First pre release


[unreleased]: https://github.com/paradoxxxzero/kalong/compare/0.1.1...HEAD
[0.1.1]: https://github.com/paradoxxxzero/kalong/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/paradoxxxzero/kalong/compare/1.3.12...0.1.0